<?php

class UserController extends CController
{
    const PAGE_SIZE=10;

    /**
     * @var string specifies the default action to be 'list'.
     */
    public $defaultAction='list';

    /**
     * @var CActiveRecord the currently loaded data model instance.
     */
    private $_model;

    /**
     * @return array action filters
     */
    public function filters()
    {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('allow',  // allow all users to perform 'list' and 'show' actions
                'actions'=>array('list','show','excel'),
                'users'=>array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions'=>array('create','update'),
                'users'=>array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions'=>array('admin','delete'),
                'users'=>array('admin'),
            ),
            array('deny',  // deny all users
                'users'=>array('*'),
            ),
        );
    }
    
    /* just trying export to excel directly and success */
    public function actionExcel()
    {
         if(Yii::app()->request->isPostRequest)
         {
            header("Content-type: application/vnd.ms-excel");
            header("Content-Disposition: attachment; filename=\"tes.xls\"");
            $output='ini cuman ngetes';
            echo $output;
            
        } else {
            echo Yii::t('lms', 'Nothing to do!');
        }
    }
    
    /**
     * Shows a particular model.
     */
    public function actionShow()
    {
        $this->render('show',array('model'=>$this->loaduser()));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'show' page.
     */
    public function actionCreate()
    {
        $model=new user;
        if(isset($_POST['user']))
        {
            $model->attributes=$_POST['user'];
            if($model->save())
                $this->redirect(array('show','id'=>$model->id));
        }
        $this->render('create',array('model'=>$model));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'show' page.
     */
    public function actionUpdate()
    {
        $model=$this->loaduser();
        if(isset($_POST['user']))
        {
            $model->attributes=$_POST['user'];
            if($model->save())
                $this->redirect(array('show','id'=>$model->id));
        }
        $this->render('update',array('model'=>$model));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'list' page.
     */
    public function actionDelete()
    {
        if(Yii::app()->request->isPostRequest)
        {
            // we only allow deletion via POST request
            $this->loaduser()->delete();
            $this->redirect(array('list'));
        }
        else
            throw new CHttpException(400,'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionList()
    {
        $criteria=new CDbCriteria;

        $pages=new CPagination(user::model()->count($criteria));
        $pages->pageSize=self::PAGE_SIZE;
        $pages->applyLimit($criteria);

        $models=user::model()->findAll($criteria);

        $this->render('list',array(
            'models'=>$models,
            'pages'=>$pages,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin()
    {
        $this->processAdminCommand();

        $criteria=new CDbCriteria;

        $pages=new CPagination(user::model()->count($criteria));
        $pages->pageSize=self::PAGE_SIZE;
        $pages->applyLimit($criteria);
        
        $format = Yii::app()->request->getParam('format');
        
         //if format is set - no pagination
        if (!isset($format)) {
            $pages->applyLimit($criteria);
        }

        $sort=new CSort('User');
        $sort->defaultOrder = "username";
        $sort->applyOrder($criteria);

        $models=User::model()->findAll($criteria);

        $params = array(
                'models'=>$models,
                'pages'=>$pages,
                'sort'=>$sort,
                //'filters'=>$filters,
                //'isEdit'=>UserIdentity::canEditUsers(),
                'format'=>isset($format)?$format:''
        );
      
        if (Yii::app()->request->isAjaxRequest) {
            //$this->renderPartial('adminList', $params);
            $this->renderPartial('admin', $params);
        } else {
            $this->render('admin', $params);
        }
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the primary key value. Defaults to null, meaning using the 'id' GET variable
     */
    public function loaduser($id=null)
    {
        if($this->_model===null)
        {
            if($id!==null || isset($_GET['id']))
                $this->_model=user::model()->findbyPk($id!==null ? $id : $_GET['id']);
            if($this->_model===null)
                throw new CHttpException(404,'The requested page does not exist.');
        }
        return $this->_model;
    }

    /**
     * Executes any command triggered on the admin page.
     */
    protected function processAdminCommand()
    {
        if(isset($_POST['command'], $_POST['id']) && $_POST['command']==='delete')
        {
            $this->loaduser($_POST['id'])->delete();
            // reload the current page to avoid duplicated delete actions
            $this->refresh();
        }
    }
}
